start

# posplit

Takes an existing PO file and splits it into three components: translated, untranslated and fuzzy. This is useful for reviewing translations or for extracting good translations from a compendium file.

## Prerequisites

GNU Gettext

## Usage

    posplit ./file.po

Where:

file.po | is an existing PO file or PO compendium

## Bugs

Some relative path bugs thus the need for ./ before file.po